// simple example application:
// demonstrates the use of device tables, how to boot, load a process and read a data field.

package de.adwin.examples;

import java.io.File;
import java.io.IOException;
import java.io.FileReader; 
import java.net.InetAddress;
import java.net.UnknownHostException;
import de.adwin.driver.ADwinDevice;
import de.adwin.driver.ADwinCommunicationError;

class simple
{
	public static void main (String args[])
	{
		String basePathName = "";
		
		if (args.length != 2)
		{
			System.err.println ("Please specify an IP address and the processor\nof an ADwin System on the command line");
			System.err.println ("\nExample: java de.adwin.examples.simple 192.168.1.1 T9");
			return;
		}
		
		if (new File ("/opt/adwin/share/btl").exists ())	// See where the BTL files are....
			basePathName = "/opt/adwin/share/btl/";			// (Linux old)
		else if (new File ("/etc/adwin/ADWINDIR").exists ())
		{													// (Linux new)
			try
			{
				FileReader fr = new FileReader ("/etc/adwin/ADWINDIR");
				char addir[] = new char[500];
				fr.read (addir, 0, 500);
				fr.close ();
				int n = 0;
				while (addir[n] != 0 && addir[n] != '\n' && addir[n] != 10)
					basePathName += addir[n++];
				basePathName += "/share/btl/";
				
			}
			catch (IOException ioe)
			{
				System.err.println ("I/O-Error when reading from /etc/adwin/ADWINDIR - " + ioe.getMessage ());
				return;
			}
		}
		else
			basePathName = "c:\\adwin\\";					// Windows
		
		ADwinDevice ad = new ADwinDevice ();
		try									// Add the given ADwin System to the device table,
		{
			ad.Add_Entry (1, InetAddress.getByName (args[0]), "", 3, 6543);
		}
		catch (UnknownHostException uhe)
		{
			System.err.println ("IP address " + args[0] + " is invalid - " + uhe.getMessage ());
			return;
		}
		
		try
		{
			ad.Set_DeviceNo (1);			// select it,
											// boot it with the right BTL file
			if (args[1].compareTo ("T9") == 0 || args[1].compareTo ("t9") == 0)
			{
				ad.Boot (basePathName + "adwin9.btl");
				ad.Load_Process ("simple.T91");
			}
			else if (args[1].compareTo ("T10") == 0 || args[1].compareTo ("t10") == 0)
			{
				ad.Boot (basePathName + "adwin10.btl");
				ad.Load_Process ("simple.TA1");
			}
			else if (args[1].compareTo ("T11") == 0 || args[1].compareTo ("t11") == 0)
			{
				ad.Boot (basePathName + "adwin11.btl");
				ad.Load_Process ("simple.TB1");
			}
			else
			{
				System.err.println ("Sorry, only T9, T10 and T11 are supported ate the moment.");
				return;
			}
			
			ad.Start_Process (1);			// This process sets Par_1 when it is finished initializing,
			while (ad.Get_Par (1) != 1);	// please see the simple.bas file for details. 
			
			String s = ad.GetData_String (1);	// Read a string from the ADwin system and display it
			System.out.println ("String read: \"" + s + "\"");
			
			int IntData[] = new int[10];		// Read an integer data field
			ad.GetData_Long (2, IntData, 1, 10);
			System.out.print ("Integers read: ");
			for (int n = 0; n < 10; n++)
				System.out.print (IntData[n] + ((n < 9) ? ", " : "\n"));
		}
		catch (ADwinCommunicationError ace)
		{
			ace.printStackTrace ();
			if (ace.getCode () == 200)					// (File not found)
				System.out.println ("\nPossible reasons: The ADwin software (especially the BTL files) is not\n" + 
						"properly installed, or the process file (simple.T91, simple.TA1 or simple.TB1)\nis not in the current " +
						"directory");
			else if (ace.getCode () == 2001)			// (Network timeout)
				System.out.println ("\nPlease check if your ADwin system is properly connected and that you\n" +
						"did not mistype its IP address");
			else if (ace.getCode () == 1 || ace.getCode () == 2)	// (Timeout from or to link)
				System.out.println ("\nPossble reasons: The simple.* files are corrupted, invalid BTL files or\n" +
						"wrong processor specified");
		}
	}
}